Index: src/arm/full-codegen-arm.cc |
diff --git a/src/arm/full-codegen-arm.cc b/src/arm/full-codegen-arm.cc |
index bb937519b235bb50fd5b326889b6b06f4930e9ad..d2bd05875b6d153bf604fb684dedf7eba0084c44 100644 |
--- a/src/arm/full-codegen-arm.cc |
+++ b/src/arm/full-codegen-arm.cc |
@@ -1306,9 +1306,9 @@ void FullCodeGenerator::EmitLoadGlobalCheckExtensions(Variable* var, |
__ Move(next, current); |
} |
__ bind(&loop); |
// Terminate at global context. |
__ ldr(temp, FieldMemOperand(next, HeapObject::kMapOffset)); |
- __ LoadRoot(ip, Heap::kGlobalContextMapRootIndex); |
+ __ LoadRoot(ip, Heap::kNativeContextMapRootIndex); |
__ cmp(temp, ip); |
__ b(eq, &fast); |
// Check that extension is NULL. |
@@ -2759,7 +2759,7 @@ void FullCodeGenerator::EmitIsStringWrapperSafeForDefaultValueOf( |
__ JumpIfSmi(r2, if_false); |
__ ldr(r2, FieldMemOperand(r2, HeapObject::kMapOffset)); |
__ ldr(r3, ContextOperand(cp, Context::GLOBAL_INDEX)); |
- __ ldr(r3, FieldMemOperand(r3, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r3, FieldMemOperand(r3, GlobalObject::kNativeContextOffset)); |
__ ldr(r3, ContextOperand(r3, Context::STRING_FUNCTION_PROTOTYPE_MAP_INDEX)); |
__ cmp(r2, r3); |
__ b(ne, if_false); |
@@ -3039,7 +3039,7 @@ void FullCodeGenerator::EmitRandomHeapNumber(CallRuntime* expr) { |
if (CpuFeatures::IsSupported(VFP2)) { |
__ PrepareCallCFunction(1, r0); |
__ ldr(r0, ContextOperand(context_register(), Context::GLOBAL_INDEX)); |
- __ ldr(r0, FieldMemOperand(r0, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r0, FieldMemOperand(r0, GlobalObject::kNativeContextOffset)); |
__ CallCFunction(ExternalReference::random_uint32_function(isolate()), 1); |
CpuFeatures::Scope scope(VFP2); |
@@ -3061,7 +3061,7 @@ void FullCodeGenerator::EmitRandomHeapNumber(CallRuntime* expr) { |
__ PrepareCallCFunction(2, r0); |
__ ldr(r1, ContextOperand(context_register(), Context::GLOBAL_INDEX)); |
__ mov(r0, Operand(r4)); |
- __ ldr(r1, FieldMemOperand(r1, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r1, FieldMemOperand(r1, GlobalObject::kNativeContextOffset)); |
__ CallCFunction( |
ExternalReference::fill_heap_number_with_random_function(isolate()), 2); |
} |
@@ -3459,7 +3459,7 @@ void FullCodeGenerator::EmitGetFromCache(CallRuntime* expr) { |
int cache_id = Smi::cast(*(args->at(0)->AsLiteral()->handle()))->value(); |
Handle<FixedArray> jsfunction_result_caches( |
- isolate()->global_context()->jsfunction_result_caches()); |
+ isolate()->native_context()->jsfunction_result_caches()); |
if (jsfunction_result_caches->length() <= cache_id) { |
__ Abort("Attempt to use undefined cache."); |
__ LoadRoot(r0, Heap::kUndefinedValueRootIndex); |
@@ -3472,7 +3472,7 @@ void FullCodeGenerator::EmitGetFromCache(CallRuntime* expr) { |
Register key = r0; |
Register cache = r1; |
__ ldr(cache, ContextOperand(cp, Context::GLOBAL_INDEX)); |
- __ ldr(cache, FieldMemOperand(cache, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(cache, FieldMemOperand(cache, GlobalObject::kNativeContextOffset)); |
__ ldr(cache, ContextOperand(cache, Context::JSFUNCTION_RESULT_CACHES_INDEX)); |
__ ldr(cache, |
FieldMemOperand(cache, FixedArray::OffsetOfElementAt(cache_id))); |
@@ -4450,7 +4450,7 @@ void FullCodeGenerator::PushFunctionArgumentForContextAllocation() { |
Scope* declaration_scope = scope()->DeclarationScope(); |
if (declaration_scope->is_global_scope() || |
declaration_scope->is_module_scope()) { |
// Contexts nested in the global context have a canonical empty function |
// as their closure, not the anonymous closure containing the global |
// code. Pass a smi sentinel and let the runtime look up the empty |
// function. |
@@ -1306,9 +1306,9 @@ void FullCodeGenerator::EmitLoadGlobalCheckExtensions(Variable* var, |
} |
__ bind(&loop); |
- // Terminate at global context. |
+ // Terminate at native context. |
__ ldr(temp, FieldMemOperand(next, HeapObject::kMapOffset)); |
@@ -4450,7 +4450,7 @@ void FullCodeGenerator::PushFunctionArgumentForContextAllocation() { |
if (declaration_scope->is_global_scope() || |
declaration_scope->is_module_scope()) { |
- // Contexts nested in the global context have a canonical empty function |
+ // Contexts nested in the native context have a canonical empty function |
// as their closure, not the anonymous closure containing the global |
// code. Pass a smi sentinel and let the runtime look up the empty |